rmd_convert: Rmd Convert

Description Usage Arguments Examples

Description

Converts .Rmd files to .R files (and others).

Usage

1
rmd_convert(input, keep.txt = TRUE)

Arguments

keep.txt

If TRUE, all lines outside of code chunks will be commented out. If FALSE, all lines outside of code chunks will be deleted.

Examples

1
rmd_convert('test.R', keep.txt = FALSE)

sndean/RmdTo documentation built on May 17, 2019, 8:45 p.m.