Description Usage Arguments Examples
Converts .Rmd files to .R files (and others).
1 | rmd_convert(input, keep.txt = TRUE)
|
keep.txt |
If TRUE, all lines outside of code chunks will be commented out. If FALSE, all lines outside of code chunks will be deleted. |
1 | rmd_convert('test.R', keep.txt = FALSE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.